@@ -179,14 +179,10 @@ uint ArchiveProtocolBase::computeArchiveDirSize(const KArchiveDirectory *dir)
     return totalSize;
 }
 
-KIO::StatDetails ArchiveProtocolBase::getStatDetails()
+KIO::StatDetails ArchiveProtocolBase::getStatDetails() const
 {
-    // takes care of converting old metadata details to new StatDetails
-    // TODO KF6 : remove legacy "details" code path
-    KIO::StatDetails details;
-    const QString statDetails = metaData(QStringLiteral("statDetails"));
-    details = statDetails.isEmpty() ? KIO::StatDefaultDetails : static_cast<KIO::StatDetails>(statDetails.toInt());
-    return details;
+    const QString statDetails = metaData(QStringLiteral("details"));
+    return statDetails.isEmpty() ? KIO::StatDefaultDetails : static_cast<KIO::StatDetails>(statDetails.toInt());
 }
 
 void ArchiveProtocolBase::createRootUDSEntry(KIO::UDSEntry &entry)
