@@ -9,8 +9,8 @@
 #ifndef KMTPDINTERFACE_H
 #define KMTPDINTERFACE_H
 
-#include <QObject>
 #include "daemoninterface.h"
+#include <QObject>
 
 class KMTPDeviceInterface;
 
@@ -32,7 +32,7 @@ public:
     KMTPDeviceInterface *deviceFromName(const QString &friendlyName);
     KMTPDeviceInterface *deviceFromUdi(const QString &udi);
 
-    QVector<KMTPDeviceInterface *> devices();
+    QList<KMTPDeviceInterface *> devices();
 
     // D-Bus properties
     QString version() const;
@@ -41,7 +41,7 @@ private:
     void updateDevices();
 
     org::kde::kmtp::Daemon *m_dbusInterface;
-    QVector<KMTPDeviceInterface *> m_devices;
+    QList<KMTPDeviceInterface *> m_devices;
 
 public Q_SLOTS:
     // D-Bus methods
@@ -52,5 +52,4 @@ Q_SIGNALS:
     void devicesChanged();
 };
 
-
 #endif // KMTPDINTERFACE_H
